@@ -278,6 +278,8 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb = new G("genome file")
 
+     Name: $gb = new G("genome file")   -   create a G instance
+
          Creates a G instance.
          First option is the filename of the database. Default format is
          the GenBank database.
@@ -333,6 +335,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->output()
 
+   Name: $gb->output()   -   output the G instance data to file
+
+   Description:
          Given a filename and an option, outputs the G-language data object 
          to the specified file in a flat-file database of a given format.
          The options are the same as those of new().  Default format is 'GenBank'.
@@ -344,6 +349,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 complement
 
+   Name: complement   -   get the complementary nucleotide sequence
+
+   Description:
          Given a sequence, returns its complement.
 
          eg. complement('atgc');  # returns 'gcat'
@@ -352,6 +360,10 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 translate
 
+   Name: translate   -   translate a nucleotide sequence to amino acid sequence
+
+   Description:
+
          Given a sequence, returns its translated sequence.
          Regular codon table is used.
          eg. translate('ctggtg');  # returns 'LV'
@@ -360,18 +372,27 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->seq()
 
+   Name: $gb->seq()   -   get the sequence data from G instance
+
+   Description:
          Returns the entire sequence. Same as $gb->{SEQ};
 
 =cut
 
 =head2 $gb->seq_info()
 
+   Name: $gb->seq_info()   -   display basic statistics about the data
+
+   Description:
          Prints the basic information of the genome to STDOUT.
 
 =cut
 
 =head2 $gb->getseq()
 
+   Name: $gb->getseq()   -   get nucleotide sequence of the given positions (Perl coordinates)
+
+   Description:
          Given the start and end positions (starting from 0 as in Perl),
          returns the sequence specified.
 
@@ -381,6 +402,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->get_gbkseq()
 
+   Name: $gb->get_gbkseq()   -   get nucleotide sequence of the given positions (GenBank coordinates)
+
+   Description:
          Given the start and end positions (starting from 1 as in 
          Genbank), returns the sequence specified.
 
@@ -390,6 +414,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->get_cdsseq()
 
+   Name: $gb->get_cdsseq()   -   get nucleotide sequence of the given CDS
+
+   Description:
          Given a CDS ID, returns the CDS sequence. 
          'complement' is properly parsed.
 
@@ -399,6 +426,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->get_geneseq()
 
+   Name: $gb->get_geneseq()   -   get nucleotide sequence of the given gene
+
+   Description:
          Given a CDS ID, returns the CDS sequence, or the exon sequence
          If introns are present.
          'complement' is properly parsed, and introns are spliced out.
@@ -409,6 +439,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->feature()
 
+   Name: $gb->feature()   -   get a list of feature IDs
+
+   Description:
          Returns the array of all feature IDs.
          Features are ignored when $gb->{$feature}->{on} is 0.
 
@@ -430,6 +463,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->cds()
 
+   Name: $gb->cds()   -   get a list of CDS IDs
+
+   Description:
          Returns the array of all feature IDs of CDS.
          Features are ignored when $gb->{FEATURE$i}->{on} OR
          $gb->{CDS$i}->{on} is 0.
@@ -451,24 +487,45 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->tRNA()
 
+   Name: $gb->tRNA()   -   get a list of feature IDs of tRNAs
+
+   Description:
          Returns the array of all feature IDs of tRNAs.
 
 =cut
 
 =head2 $gb->rRNA()
 
+   Name: $gb->rRNA()   -   get a list of feature IDs of rRNAs
+
+   Description:
          Returns the array of all feature IDs of rRNAs.
 
 =cut
 
+=head2 $gb->intergenic()
+
+   Name: $gb->intergenic()   -   get a list of IDs of intergenic regions
+
+   Description:
+         Returns the array of all IDs of intergenic regions.
+
+=cut
+
 =head2 $gb->gene()
 
+   Name: $gb->gene()   -   get a list of feature IDs of genes
+
+   Description:
          Returns the array of all feature IDs of genes.
 
 =cut
 
 =head2 $gb->next_feature()
 
+   Name: $gb->next_feature()   -   get the next feature ID
+
+   Description:
          Given a feature ID, returns the ID of the next feature.
          Second argument can be used to specify the type of the 
          next feature.
@@ -481,6 +538,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->next_cds()
 
+   Name: $gb->next_cds()   -   get the feature ID of next CDS
+
+   Description:
          Given a feature ID, returns the ID of the next cds.
          This is same as $gb->next_feature($featureID, 'CDS');
 
@@ -488,6 +548,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->previous_feature()
 
+   Name: $gb->previous_feature()   -   get the previous feature ID
+
+   Description:
          Given a feature ID, returns the ID of the previous feature.
          Second argument can be used to specify the type of the 
          next feature.
@@ -500,6 +563,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->previous_cds()
 
+   Name: $gb->previous_cds()   -   get the feature ID of previous CDS
+
+   Description:
          Given a feature ID, returns the ID of the previous cds.
          This is same as $gb->previous_feature($featureID, 'CDS');
 
@@ -510,6 +576,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->startcodon()
 
+   Name: $gb->startcodon()   -   get the start codon of the given CDS
+
+   Description:
          Given a CDS ID, returns the start codon.
 
          eg. $gb->startcodon("FEATURE$i"); # returns 'atg'
@@ -518,6 +587,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->stopcodon()
 
+   Name: $gb->stopcodon()   -   get the stop codon of the given CDS
+
+   Description:
          Given a CDS ID, returns the stop codon.
 
          eg. $gb->stopcodon("FEATURE$i"); # returns 'tag'
@@ -526,6 +598,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->before_startcodon()
 
+   Name: $gb->before_startcodon()   -   get the upstream sequence of the given CDS
+
+   Description:
          Given a CDS ID and length, returns the sequence upstream of 
          start codon.
 
@@ -536,6 +611,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->after_startcodon()
 
+   Name: $gb->after_startcodon()   -   get the sequence downstream of start codon of the given CDS
+
+   Description:
          Given a CDS ID and length, returns the sequence downstream of 
          start codon.
 
@@ -546,6 +624,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->before_stopcodon()
 
+   Name: $gb->before_stopcodon()   -   get the sequence upstream of stop codon of the given CDS
+
+   Description:
          Given a CDS ID and length, returns the sequence upstream of 
          stop codon.
 
@@ -556,6 +637,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->after_stopcodon()
 
+   Name: $gb->after_stopcodon()   -   get the downstream sequence of the given CDS
+
+   Description:
          Given a CDS ID and length, returns the sequence downstream of 
          stop codon.
 
@@ -566,6 +650,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->get_exon()
 
+   Name: $gb->get_exon()   -   get a list of exon sequences of the given CDS
+
+   Description:
          Given a CDS ID, returns the exon sequence.
          'complement' is properly parsed, and introns are spliced out.
 
@@ -576,6 +663,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->get_intron()
 
+   Name: $gb->intron()   -   get a list of intron sequences of the given CDS
+
+   Description:
          Given a CDS ID, returns the intron sequences as array of 
          sequences.
 
@@ -586,6 +676,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->pos2feature()
 
+   Name: $gb->pos2feature()   -   get a feature ID from position
+
+   Description:
          Given a GenBank position (sequence starting from position 1) 
          returns the feature ID (ex. FEATURE123) of the feature at
          the given position. If multiple features exist for the given
@@ -596,6 +689,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->pos2gene()
 
+   Name: $gb->pos2gene()   -   get a feature ID of CDS from position
+
+   Description:
          Given a GenBank position (sequence starting from position 1) 
          returns the feature ID (ex. FEATURE123) of the gene at
          the given position. If multiple genes exists for the given
@@ -606,6 +702,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->gene2id()
 
+   Name: $gb->gene2id()   -   get a feature ID from canonical gene name
+
+   Description:
          Given a GenBank gene name, returns the feature ID (ex. FEATURE123). 
          Returns NULL if no gene exists.
 
@@ -613,6 +712,9 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->next_locus()
 
+   Name: $gb->next_locus()   -   read the next locus and update the G instance
+
+   Description:
          Reads the next locus.
          the G instance is then updated.
 
@@ -626,19 +728,19 @@ G - G-language Genome Analysis Environment core interface module
 
 =head2 $gb->clone()
 
+   Name: $gb->clone()   -   create a copy of the G instance
+
+   Description:
          Returns cloned G instance, which is a new G instance with
          identical data. 
 
 =cut
 
-=head2 $gb->DESTROY()
-
-         Destroys the G instance.
-
-=cut
-
 =head2 $gb->del_key()
 
+   Name: $gb->del_key()   -   delete a data object from G instance
+
+   Description:
          Given a object, deletes it from the G instance structure
          eg. $gb->del_key('FEATURE1'); # deletes 'FEATURE1' hash
 
