@@ -31,23 +31,23 @@ package G::Seq::AminoAcid;
 use SubOpt;
 use G::Messenger;
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
 use SelfLoader;
 
 require Exporter;
 
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
+our @ISA = qw(Exporter);
+
+our @EXPORT = qw(
 	     calc_pI
 	     amino_info
 	     peptide_mass
 );
 
-$VERSION = '0.01';
+
+#::::::::::::::::::::::::::::::
+#        Constants
+#::::::::::::::::::::::::::::::
 
 #following values are obtained from EMBOSS
 
@@ -102,9 +102,27 @@ my %dayhoff = (
 
 __DATA__
 
-#::::::::::::::::::::::::::::::
-#        Methods Start
-#::::::::::::::::::::::::::::::
+
+
+#:::::::::::::::::::::::::::::::::
+#       Perldoc
+#:::::::::::::::::::::::::::::::::
+
+
+=head1 NAME
+
+    G::Seq::AminoAcid - Analysis methods related to amino acids.
+
+=head1 DESCRIPTION
+
+    This class is a part of G-language Genome Analysis Environment, 
+    collecting sequence analysis methods related to amio acids.
+
+=cut
+
+#:::::::::::::::::::::::::::::::::
+#       Let the code begin...
+#:::::::::::::::::::::::::::::::::
 
 sub mass{
     my $this = shift;
@@ -125,14 +143,18 @@ sub three2one{
 }
 
 
+sub 
+
 
 
 =head2 peptide_mass
+
        Author: Kazuharu Arakawa (gaou@g-language.org)
         Usage: double $mass = peptide_mass(string $aminoseq);
       Options: None.
   Description: Calculates mass of given amino acid sequence.
       History: created 2001.04.04
+
 =cut
 
 sub peptide_mass{
@@ -148,11 +170,13 @@ sub peptide_mass{
 }
 
 =head2 calc_pI
+
        Author: Kazuharu Arakawa (gaou@g-language.org)
         Usage: double $pI = calc_pI(string $aminoseq);
       Options: None.
   Description: Calculates isoelectric point of given amino acid sequence.
       History: created 2001.04.04
+
 =cut
 
 sub calc_pI{
@@ -198,12 +222,14 @@ sub calc_pI{
 }
 
 =head2 _charge
+
        Author: Kazuharu Arakawa (gaou@g-language.org)
         Usage: $charge = charge(pK, pH) for positive
                $charge = charge(pH, pK) for negative
       Options: None.
   Description: intended for internal use only
       History: created 2001.04.04
+
 =cut
 
 sub _charge {
@@ -215,12 +241,14 @@ sub _charge {
     
 
 =head2 _charge
+
        Author: Misa Nakanishi (dora@g-language.org)
         Usage: amino_info(string $aminoseq)
       Options: None.
   Description: Prints basic amino acid sequence information
       History: created 2001.04.04 
                Tuned by Kazuharu Arakawa (gaou@g-language.org)
+
 =cut
 
 sub amino_info{
@@ -299,43 +327,5 @@ sub amino_info{
 }
 
  
-sub DESTROY {
-    my $self = shift;
-}
-
 1;
 
-__END__
-
-
-
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-G::Seq::AminoAcid - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::Seq::AminoAcid was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
-
-
-
