@@ -35,23 +35,14 @@ use G::Seq::Util;
 
 use strict;
 
-BEGIN{
-    eval "use Statistics::Descriptive;";
-    if ($@){ warn "$@" };
-}
-
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
+use Statistics::Descriptive;
 use SelfLoader;
 
-
 require Exporter;
 
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
+our @ISA = qw(Exporter);
+
+our @EXPORT = qw(
 	     base_counter
 	     _base_printer
 	     base_entropy
@@ -61,23 +52,27 @@ require Exporter;
 	     base_individual_information_matrix
 	     consensus_z
 );
-$VERSION = '0.01';
-
 
 __DATA__
 
 #::::::::::::::::::::::::::::::
-#        Methods Start
+#     Perldoc
 #::::::::::::::::::::::::::::::
-sub new{
-    my $pkg = shift;
-    my $filename = shift;
-    my $option = shift;
-    my $this;
 
-    return $this;
-}
+=head1 NAME
 
+G::Seq::Consensus - Analysis methods related to sequence consensus
+
+=head1 DESCRIPTION
+
+    This class is a part of G-language Genome Analysis Environment, 
+    collecting sequence analysis methods related to sequence consensus.
+
+=cut
+
+#::::::::::::::::::::::::::::::
+#     Let the code begin...
+#::::::::::::::::::::::::::::::
 
 #base_counter ver.20010623-01
 #scripting by Koya Mori(mory@g-language.org)
@@ -720,31 +715,39 @@ sub base_individual_information_matrix{
 }
 
 
-# consensus_z ver.20010906-01
-# Author: Kazuharu "Gaou" Arakawa (gaou@g-language.org)
-# (string consensus) = &consensus_z(pointer array_of_sequences);
-#
-# pointer array_of_sequences is a reference to an array of sequences.
-# The sequences must be of same lengths.
-# eg. my @seq = ("atgc","ctaa","tttt","cttg"); &consensus_z(\@seq);
-#     returns 'cTt-'
-#
-# Options:
-#     -high      z value greater than which is significant (default: 1)
-#     -low       z value less than which is insignificant (default: 0.2)
-#     -filename  outfile name (default: consensus_z.png for -output=>"g",
-#                                       consensus_z.csv for -output=>"f")
-#     -output    "g" for graph, "f" for file, "show" for display
-#
-# Consensus with Z value greater than int high_z (default is 1) is 
-# capitalized, and consensus with Z value less than int low_z 
-# (default is 0.2) is shown as '-'.
-# This subroutine requires 
-# use Statistics::Descriptive;
-# at the beginning of the library.
-# History:
-#   20010713-01 initial posting
-#   20010906-01 update with options
+=head2 consensus_z
+
+  Name: consensus_z   -   calculate consensus in given array of sequences
+
+  Description:
+    Calculates the consensus of given list of sequences, using Z-score.
+    Consensus with Z value greater than int high_z (default is 1) is 
+    capitalized, and consensus with Z value less than int low_z 
+    (default is 0.2) is shown as '-'.
+
+  Usage:
+     $consensus_sequence = &consensus_z(\@array_of_sequences);
+
+      @array_of_sequences is a reference to an array of sequences.
+      The sequences must be of same lengths.
+       eg. consensus_z(["atgc","ctaa","tttt","cttg"]);
+      returns 'cTt-'
+
+  Options:
+     -high      z value greater than which is significant (default: 1)
+     -low       z value less than which is insignificant (default: 0.2)
+     -filename  outfile name (default: consensus_z.png for -output=>"g",
+                                       consensus_z.csv for -output=>"f")
+     -output    "g" for graph, "f" for file, "show" for display
+
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+   20010906-01 update with options
+   20010713-01 initial posting
+
+=cut
 
 sub consensus_z{
     &opt_default(high=>1, low=>0.2, output=>"show", 
@@ -816,37 +819,5 @@ sub consensus_z{
 }
 
 
-sub DESTROY {
-    my $self = shift;
-}
 
 1;
-__END__
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-G::Seq::Consensus - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::Seq::Consensus;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::Seq::Consensus was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
