@@ -30,18 +30,15 @@ use SubOpt;
 use G::Messenger;
 use G::Tools::Graph;
 
-use Statistics::Descriptive;
-
 use strict;
-use vars qw(@ISA @EXPORT);
-
+use Statistics::Descriptive;
 use SelfLoader;
 
 require Exporter;
 
-@ISA = qw(Exporter);
+our @ISA = qw(Exporter);
 
-@EXPORT = qw(
+our @EXPORT = qw(
 	     find_ori_ter
 	     gcskew
 	     cum_gcskew
@@ -59,34 +56,35 @@ require Exporter;
 );
 
 
+__DATA__
+
+#:::::::::::::::::::::::::::::::::
+#       Perldoc
+#:::::::::::::::::::::::::::::::::
+
 
 =head1 NAME
 
-    G::Seq::GCskew - component of G-language Genome Analysis Environment
+    G::Seq::GCskew - Analysis methods related to GC skew and genomic strand bias
 
 =head1 DESCRIPTION
 
     This class is a part of G-language Genome Analysis Environment, 
     collecting sequence analysis methods related to GC skew.
 
-=head1 AUTHOR
-    
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
-
-=head1 SYNOPSIS
-
 =cut
 
 
-__DATA__
 
-#::::::::::::::::::::::::::::::
-#        Methods Start
-#::::::::::::::::::::::::::::::
+#:::::::::::::::::::::::::::::::::
+#       Let the code begin...
+#:::::::::::::::::::::::::::::::::
 
 
 =head2 view_cds
 
+  Name: view_cds   -   displays a graph of nucleotide contents around start and stop codons
+
   Description:
     This method creates a graph showing the average A,T,G,C contents
     around start/stop codons. This is useful to view consensus around
@@ -106,7 +104,7 @@ __DATA__
                (default: "show")
 
   Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
     20010906-01 initial posting
@@ -204,8 +202,10 @@ sub view_cds{
 
 =head2 find_ori_ter
 
+ Name: find_ori_ter   -   predict the replication origin and terminus in bacterial genomes
+
  Description:
-    Predicts the replicational origin and terminus
+    Predicts the replicational origin and terminus in circular bacterial genomes.
 
  Usage:
     (int origin, int terminus) = find_ori_ter(G instance);
@@ -216,7 +216,7 @@ sub view_cds{
    -keto      use keto skew for calculation (default: 0)
 
  Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
    20060711-01 added purine and keto options
@@ -274,6 +274,8 @@ sub find_ori_ter {
 
 =head2 rep_ori_ter
 
+ Name: rep_ori_ter   -   get the positions of replication origin and terminus
+
  Description:
     This method returns the replicational origin and terminus.
     If not known, the origin and terminus is predicted using
@@ -339,6 +341,8 @@ sub rep_ori_ter {
 
 =head2 leading_strand 
 
+ Name: leading_strand   -   get the sequences of leading strands
+
  Description:
    This method returns the leading strands from origin and terminus 
    of replication calculated with rep_ori_ter()
@@ -350,7 +354,7 @@ sub rep_ori_ter {
     none
 
   Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
     20011030-01 initial posting
@@ -380,6 +384,8 @@ sub leading_strand {
 
 =head2 gcskew
 
+ Name: gcskew   -   calculate the GC skew of the given genome
+
  Description:
    This program calculates and graphs the GC skew. 
 
@@ -398,7 +404,7 @@ sub leading_strand {
                                           "gcskew.csv" for -output=>"f")
 
  Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
    20060711-01 added purine and keto skew
@@ -498,6 +504,8 @@ sub gcskew {
 
 =head2 cum_gcskew
 
+ Name: cum_gcskew   -   calculate the cumulative GC skew of the given genome
+
  Description:
    This program calculates and graphs the cumulative GC skew. 
 
@@ -516,7 +524,7 @@ sub gcskew {
    -application application to open png image (default: "gimv")
 
  Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
    20070429-01 minor bug fix related to output=>"f" option
@@ -621,6 +629,8 @@ sub cum_gcskew {
 
 =head2 genomicskew
 
+ Name: genomicskew   -   calculate the GC skew in different  regions of the given genome
+
  Description:
    This program graphs the GC skew for the whole genome, coding regions,
    intergenic regions, and the third codon.
@@ -639,7 +649,7 @@ sub cum_gcskew {
    -application application to open png image (default: "gimv")
 
  Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
    20040610-01 updated to handle introns and exons
@@ -785,6 +795,8 @@ sub genomicskew {
 
 =head2 gcwin
 
+ Name: gcwin   -   calculate the GC content along the given genome
+
  Description:
    This program calculates and graphs the GC content.
 
@@ -803,7 +815,7 @@ sub genomicskew {
                                           "gcwin.csv" for -output=>"f")
 
  Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
    20070429-01 minor bug fix related to output=>"f" option
@@ -894,6 +906,8 @@ sub gcwin  {
 
 =head2 query_strand 
 
+  Name: query_strand   -   get the strand name (leading or lagging) from the given position
+
   Description:
     Given a position and strand information (direct or complement), 
     returns whether the specified position is in the leading or lagging strand.
@@ -910,7 +924,7 @@ sub gcwin  {
                   (default: direct)
 
   Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
     20020218-01 initial posting
@@ -973,6 +987,8 @@ sub query_strand {
 
 =head2 query_arm
 
+  Name: query_arm   -   get the replication arm name (left or right) from the given position
+
   Description:
     Given a position, returns whether the specified position is in the 
     left or right arm of the circular chromosome.
@@ -984,7 +1000,7 @@ sub query_strand {
     None.
 
   Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
     20070112-01 initial posting
@@ -1026,6 +1042,8 @@ sub query_arm{
 
 =head2 set_strand 
 
+  Name: set_strand   -   set replication strand and arm information to given G instance
+
   Description:
     Sets $gb->{$cds}->{strand} and $gb->{$cds}->{arm} using
     query_strand() and query_arm(), indicating in which strand
@@ -1038,7 +1056,7 @@ sub query_arm{
     None.
 
   Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
     20070112-01 initial posting
@@ -1062,6 +1080,8 @@ sub set_strand{
 
 =head2 set_gc3
 
+  Name: set_gc3   -   set GC content in 3rd codon position of all genes
+
   Description:
     Sets $gb->{$cds}->{gc3}, GC content in 3rd codon position.
     Value is in decimal (eg. 0.56345).
@@ -1073,7 +1093,7 @@ sub set_strand{
     None.
 
   Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
     20070116-01 initial posting
@@ -1109,6 +1129,8 @@ sub set_gc3{
 
 =head2 genes_from_ori
 
+ Name: genes_from_ori   -   get a list of CDS IDs ordered in the distance from origin of replication
+
  Description:
    This program lists genes in order relative to the position of 
    replication origin in either right or left half of the bacterial
@@ -1126,7 +1148,7 @@ sub set_gc3{
    Origin and terminus of replication is obtained from rep_ori_ter()
 
  Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
    20070106-01 initial posting
@@ -1200,6 +1222,8 @@ sub genes_from_ori{
 
 =head2 dist_in_cc
 
+ Name: dist_in_cc   -   calculates the distance between two loci in circular chromosomes
+
  Description:
    This program calculates the distance between two loci in 
    circular chromosomes, mostly useful to calculate the
@@ -1214,7 +1238,7 @@ sub genes_from_ori{
    Origin and terminus of replication is obtained from rep_ori_ter()
 
  Author: 
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
    20070112-01 initial posting
