@@ -39,22 +39,15 @@ use G::DB::SDB;
 use strict;
 use Cwd;
 use GD;
-
-BEGIN{
-    eval "use SVG;";
-    if($@){ warn "$@" };
-}
-
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
+use SVG;
 use SelfLoader;
 
 
 require Exporter;
 
-@ISA = qw(Exporter);
+our @ISA = qw(Exporter);
 
-@EXPORT = qw(
+our @EXPORT = qw(
 	     find_king_of_gene
 	     atcgcon
 	     cds_echo
@@ -72,24 +65,23 @@ require Exporter;
 	     _translate
 	     );
 
+
+#:::::::::::::::::::::::::::::::::
+#       Perldoc
+#:::::::::::::::::::::::::::::::::
+
+
 =head1 NAME
 
-  G::Seq::Util - component of G-language Genome Analysis Environment
+  G::Seq::Util - Miscellaneous analysis methods related to sequence analysis.
 
 =head1 DESCRIPTION
 
     This class is a part of G-language Genome Analysis Environment, 
-    collecting miscellaneous analysis methods using the genome sequence.
-
-=head1 AUTHOR
-    
-    Kazuharu Gaou Arakawa (gaou@g-language.org)
-
-=head1 SYNOPSIS
+    collecting miscellaneous sequence analysis methods.
 
 =cut
 
-
 #::::::::::::::::::::::::::::::
 #        Constants
 #::::::::::::::::::::::::::::::
@@ -236,21 +228,30 @@ sub molecular_weight {
 }
 
 
-# genome_map ver.20010906-01
-# Author: Kazuharu Gaou Arakawa
-# Usage: NULL = &genome_map(pointer G instance); 
-# Options:
-# -name      print gene name (default: 1)
-# -output    "g" for graph, "show" for display (default: "show") 
-# Description:
-#  This method creates a nice looking map of the genome, showing
-#  the partial ATGC contents and genes in either direct and complement
-#  strands.
-#  A is shown in red, T is shown in green, 
-#  G is shown in yellow, and C is shown in blue. 
-# Requirements:
-#  SubOpt.pm
-#  GD.pm
+
+
+=head2 genome_map
+
+  Description:
+    This method creates a map of the genome, showing the local 
+    nucleotide contents and positions of genes.
+    A is shown in red, T is shown in green, 
+    G is shown in yellow, and C is shown in blue. 
+
+  Usage:
+    NULL = genome_map($gb);
+
+ Options:
+    -name      print gene name (default: 1)
+    -output    "g" for graph, "show" for display (default: "show") 
+
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+   20010906-01 initial posting
+
+=cut
 
 sub genome_map {
     &opt_default(output=>"show", name=>1, window=>50, amp=>1.5);
@@ -528,29 +529,34 @@ sub genome_map {
     }
 }
 
+=head2 genome_map2
 
+  Description:
+    This method creates a map of the genome, showing the local 
+    nucleotide contents and positions of genes using SVG.
+    A is shown in red, T is shown in green, 
+    G is shown in yellow, and C is shown in blue. 
+
+  Usage:
+    NULL = genome_map2($gb);
+
+ Options:
+    -window    length of one pixel (default: 50)
+    -type      type of features to print (default: CDS)
+    -output    "g" for graph, "show" for display (default: "show") 
+    -start     start position (default: 1)
+    -end       end position (default: 100000)
+    -filename  output file name (default: genome_map.svg)
+    -ptt       ptt filename
+    
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+    20020906-01 initial posting
+
+=cut
 
-# genome_map2 ver.20020906-01
-# Author: Kazuharu Gaou Arakawa
-# Usage: NULL = &genome_map2(pointer G instance); 
-# Options:
-# -window    length of one pixel (default: 50)
-# -type      type of features to print (default: CDS)
-# -output    "g" for graph, "show" for display (default: "show") 
-# -start     start position (default: 1)
-# -end       end position (default: 100000)
-# -filename  output file name (default: genome_map.svg)
-# -ptt       ptt filename
-# Description:
-#  This method creates a nice looking map of the genome, showing
-#  the partial ATGC contents and genes in either direct and complement
-#  strands.
-#  A is shown in red, T is shown in green, 
-#  G is shown in yellow, and C is shown in blue. 
-# Requirements:
-#  SubOpt.pm
-#  SVG.pm
-#  G::Tools::GPAC
 
 sub genome_map2 {
     &opt_default(output=>"show", window=>50, type=>"CDS", 
@@ -1251,19 +1257,28 @@ sub pasteseq{
 }
 
 
-# plasmid_map ver.20020905-01
-# Author: Kazuharu Gaou Arakawa
-# Usage: &plasmid_map(instance G)
-# Options:
-#   -ptt       ptt file name
-#   -output    g|show (default:show)
-#   -filename  output file name (default:plasmid_map.svg)
-# Description:
-#   This method creates a plasmid map image with SVG.
-# Requirements
-#   SVG
-#   G::Tools::GPAC
-#   Cwd
+
+=head2 plasmid_map
+
+  Description:
+   This method creates a plasmid map image with SVG.
+
+  Usage:
+    NULL = plasmid_map($gb);
+
+ Options:
+   -ptt       ptt file name
+   -output    g|show (default:show)
+   -filename  output file name (default:plasmid_map.svg)
+
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+   20020905-01 initial posting
+
+=cut
+
 
 sub plasmid_map{
     opt_default(ptt=>'', output=>'show', filename=>"plasmid_map.svg", cgi=>0);
