@@ -37,8 +37,6 @@ use XML::Simple;
 use LWP::UserAgent;
 use G::Shell::Help;
 
-our $VERSION = '1.00';
-
 require Exporter;
 
 our @ISA = qw(Exporter);
@@ -48,6 +46,22 @@ our @EXPORT = qw(
 		 entrez
 		 );
 
+#:::::::::::::::::::::::::::::::::
+#       Perldoc
+#:::::::::::::::::::::::::::::::::
+
+
+=head1 NAME
+
+  G::Shell::EUtils - G-language Shell helper module for searching NCBI.
+
+=head1 DESCRIPTION
+
+  This class is a part of G-language Genome Analysis Environment, 
+  providing functions for searching NCBI with EUtilities.
+
+=cut
+
 #::::::::::::::::::::::::::::::
 #          Variables
 #::::::::::::::::::::::::::::::
@@ -71,6 +85,8 @@ map {$einfo{$_} = 1} qw(
 
 =head2 pubmed
 
+  Name: pubmed   -   search PubMed in G-language Shell
+
   Description:
     Search PubMed with keyword through EUtilities. This is 
     intended for quick lookup through G-language Shell, so 
@@ -107,6 +123,8 @@ sub pubmed {
 
 =head2 entrez
 
+  Name: entrez   -   search NCBI Entrez in G-language Shell
+
   Description:
     Search NCBI Entrez with keyword through EUtilities. 
     This is intended for quick lookup through G-language Shell, 
@@ -279,59 +297,4 @@ sub entrez {
     }
 }
 
-
-
-
-
 1;
-__END__
-
-# Below is stub documentation for your module. You'd better edit it!
-
-=head1 NAME
-
-G::Shell::EUtils - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::Shell::EUtils;
-  blah blah blah
-
-=head1 ABSTRACT
-
-  This should be the abstract for Shell.
-  The abstract is used when making PPD (Perl Package Description) files.
-  If you don't want an ABSTRACT you should also edit Makefile.PL to
-  remove the ABSTRACT_FROM option.
-
-=head1 DESCRIPTION
-
-Stub documentation for Shell, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 SEE ALSO
-
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
-
-=head1 AUTHOR
-
-Kazuharu Arakawa, E<lt>gaou@localdomainE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2007 by Kazuharu Arakawa
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
-
-=cut
