@@ -33,17 +33,33 @@ package G::Shell::Help;
 
 use strict;
 use File::Find;
-
-our $VERSION = '1.00';
+use String::Approx 'amatch';
 
 require Exporter;
 
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
-	     help
+		 help
+		 buildHelpDB
 	     );
 
+#:::::::::::::::::::::::::::::::::
+#       Perldoc
+#:::::::::::::::::::::::::::::::::
+
+
+=head1 NAME
+
+  G::Shell::Help - G-language Shell helper module for command references
+
+=head1 DESCRIPTION
+
+  This class is a part of G-language Genome Analysis Environment, 
+  providing functions for "help" features of the G-language Shell.
+
+=cut
+
 #::::::::::::::::::::::::::::::
 #          Variables
 #::::::::::::::::::::::::::::::
@@ -55,24 +71,31 @@ my %pdoc;
 #::::::::::::::::::::::::::::::
 
 
-sub buildPDocDB{
+sub buildHelpDB{
     my $bpPath = qx/perldoc -l Bio::Perl/;
     my $gPath = qx/perldoc -l G::Skyline/;
+    my $rcmdPath = qx/perldoc -l Rcmd::Clustering/;
     
     $bpPath =~ s/Perl.pm//;
     $gPath =~ s/\/Skyline.pm//;
+    $rcmdPath =~ s/\/Clustering.pm//;
     
     chomp($bpPath);
     chomp($gPath);
+    chomp($rcmdPath);
 
     find({"wanted"=>\&process_g, "follow"=>1}, $gPath . '.pm');
     find({"wanted"=>\&process_g, "follow"=>1}, $gPath);
+    find({"wanted"=>\&process_g, "follow"=>1}, $rcmdPath . '.pm');
+    find({"wanted"=>\&process_g, "follow"=>1}, $rcmdPath);
     find({"wanted"=>\&process_bp, "follow"=>1}, $bpPath);
 }
 
 
 =head2 help
 
+  Name: help   -   G-language Shell help command
+
   Description:
     G-language Shell help command. This command seaches through
     G-language GAE manual and BioPerl documentation (Perldoc)
@@ -88,7 +111,7 @@ sub buildPDocDB{
     or BioPerl object name with class name
         eg. Bio::Perl::get_sequence
 
- Options:
+  Options:
    -s         search through documentation with keyword
    -g         same as above, but only for G-language GAE manual
    -bp        same as above, but only for BioPerl manual
@@ -103,7 +126,7 @@ sub buildPDocDB{
 
 
 sub help{
-    buildPDocDB() unless(scalar %pdoc);
+    buildHelpDB() unless(scalar %pdoc);
 
     my $key = shift || "help";
 
@@ -129,10 +152,21 @@ sub help{
 	}
 	    
 	if(scalar(@tmp)){
-	    $ans = "     Found keyword \"$key\" in the following manual pages.\n";
+	    $ans = "     Found keyword \"$key\" in the following manual pages.\n\n";
 	    
 	    foreach my $entry (@tmp){
-		$ans .= "              " . $entry . "\n";
+		my $tmp = $pdoc{$entry};
+
+		my $abstract;
+		if($tmp =~ /Name:\s*(.*)(   -   .*?)\_\_\%\%\%\%\%\_\_/){
+		    $abstract = $2;
+		}
+
+		if($entry =~ /Bio::/){
+		    $ans .= sprintf("              %s\n",$entry);
+		}elsif($entry){
+		    $ans .= sprintf("       %-30s%s\n",$entry, $abstract);
+		}
 	    }
 	}
 
@@ -145,7 +179,10 @@ sub help{
 
 	if(length $ans){
 	    $ans =~ s/\_\_\%\%\%\%\%\_\_/\n/g;
-	    $ans = "\n  Entry: $key\n". $ans;
+
+	    unless($ans =~ /Name: (.*)   -   (.*)\n/){
+		$ans = "\n  Name: $key\n". $ans;
+	    }
 	}else{
 	    $ans = "     Keyword: \"$key\" not found in manual.\n\n";
 	    my $lckey = lc($key);
@@ -157,6 +194,14 @@ sub help{
 		}
 	    }
 	    
+	    unless(scalar(@tmp)){
+		foreach my $keyword (sort keys %pdoc){
+		    if(amatch($lckey, ['i 1'], lc($keyword))){
+			push(@tmp, $keyword);
+		    }
+		}
+	    }
+
 	    if(scalar(@tmp)){
 		$ans .= "     Did you mean:\n";
 		
@@ -172,15 +217,13 @@ sub help{
     }
 }
 
-
-
 sub process_g{
     next unless(/\.pm$/);
 
     open(FILE, $File::Find::name) || die($File::Find::name, " ", $!);
     while(<FILE>){
 	chomp;
-	if(/\=head2\s+(.*)\s*$/){
+	if(/^\s*\=head2\s+(.*)\s*$/){
 	    my $subname = $1;
 
 	    while(<FILE>){
@@ -207,7 +250,7 @@ sub process_bp{
     open(FILE, $File::Find::name) || die($!);
     while(<FILE>){
 	chomp;
-	if(/\=head2\s+(\S*)\s*/){
+	if(/^\s*\=head2\s+(\S*)\s*/){
 	    my $subname = $class . '::' . $1;
 	    next if ($subname =~ /Mailing Lists/ || $subname =~ /Reporting Bugs/);
 
@@ -221,59 +264,4 @@ sub process_bp{
     close(FILE);
 }
 
-
-
-
-
 1;
-__END__
-
-# Below is stub documentation for your module. You'd better edit it!
-
-=head1 NAME
-
-Shell - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use Shell;
-  blah blah blah
-
-=head1 ABSTRACT
-
-  This should be the abstract for Shell.
-  The abstract is used when making PPD (Perl Package Description) files.
-  If you don't want an ABSTRACT you should also edit Makefile.PL to
-  remove the ABSTRACT_FROM option.
-
-=head1 DESCRIPTION
-
-Stub documentation for Shell, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 SEE ALSO
-
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
-
-=head1 AUTHOR
-
-Kazuharu Arakawa, E<lt>gaou@localdomainE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2007 by Kazuharu Arakawa
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
-
-=cut
