@@ -32,16 +32,20 @@
 package Rcmd;
 
 use strict;
-use vars qw($VERSION);
+use Carp qw(croak);
+use File::Copy;
 
-require Exporter;
+require Rcmd::Clustering;
+require Rcmd::Normality;
 
-$VERSION = '1.01';
+our @ISA = qw(Rcmd::Clustering Rcmd::Normality);
+
+our $VERSION = '1.2';
 
 srand(time ^ $$ ^ unpack "%L*", `ps axww | gzip`);
 
 ######################################
-#         Main Methods               #
+#       Let the code begin...
 ######################################
 
 my $save = '--no-save';
@@ -56,19 +60,54 @@ sub new {
     my $cmd = "/tmp/$uniq.cmd";
     my $log = "/tmp/$uniq.log";
 
+    my $tmpcmd = "/tmp/$uniq.tmpcmd";
+    my $tmplog = "/tmp/$uniq.tmplog";
+
+    my $rPath;
+    eval {
+	$rPath = `/usr/bin/which R`;
+    };
+
+    unless(length($rPath)){
+	croak("R language not found in your system.");
+	return;
+    }
+
     bless { 
 	cmd => $cmd, 
-	log => $log
+	log => $log,
+	tmpcmd => $tmpcmd,
+	tmplog => $tmplog,
+	sessioncmd => $cmd,
+	sessionlog => $log
     }
 }
 
+sub set_mode{
+    my $this = shift;
+    my $option = shift;
+
+    if($option eq 'tmp'){
+	$this->{cmd} = $this->{tmpcmd};
+	$this->{log} = $this->{tmplog};
+    }else{
+	unlink($this->{tmpcmd});
+	unlink($this->{tmplog});
+	$this->{cmd} = $this->{sessioncmd};
+	$this->{log} = $this->{sessionlog};
+    }
+
+}
+
 sub DESTROY{
     my $this = shift;
     if (length $output){
-	system("cp $this->{cmd} $output");
+	copy($this->{cmd}, $output);
     }
     unlink $this->{cmd};
     unlink $this->{log};
+    unlink $this->{tmpcmd};
+    unlink $this->{tmplog};
 
     foreach my $file (@tmpdat){
 	unlink $file;
@@ -120,7 +159,7 @@ sub exec{
     print CMD $request;
     close(CMD);
 
-    system('/usr/bin/env R $save --slave < '
+    system("/usr/bin/env R $save --slave < "
 	   . $this->{cmd} . " >& " . $this->{log});
 
     open(DATA, $this->{log});
@@ -160,7 +199,10 @@ sub exec{
 
 1;
 __END__
-# Below is the stub of documentation for your module. You better edit it!
+
+##############################
+#       Perldoc
+##############################
 
 =head1 NAME
 
@@ -176,8 +218,14 @@ Rcmd - Perl interface for R language
 
 =head1 DESCRIPTION
 
-  Note: We recommend using R/S Perl (http://www.omegahat.org/RSPerl/) instead
-  of this module in UNIX environment. Follow instructions of the above web site.
+=cut 
+
+=head2 $rcmd = new Rcmd()
+
+  Name: $rcmd = new Rcmd()   -   create an instance of R language session
+
+  This module is a simple interface to open-source R statistics language
+  availabe under GPL at http://www.r-project.org/.
 
   Rcmd enables Perl manipulation of the R language by simply executing them
   through $rcmd->exec() function. Input is an array of R commands.
@@ -225,14 +273,22 @@ Rcmd - Perl interface for R language
 
   system("gs /tmp/out.ps");
 
-  #R language is S-plus clone availabe with GPL at http://www.r-project.org/
+  You can easily add Perl array data by $rcmd->array() for numerical data, or
+  by $rcmd->sarray() for character data. For example:
+
+    $rcmd->array("array1", 1, 2, 3, 4, 5);
+
+  or
+
+    $rcmd->sarray("array2", "a", "b", "c", "d", "e");
+
+  Note: We recommend using R/S Perl (http://www.omegahat.org/RSPerl/) instead
+  of this module in UNIX environment. Follow instructions of the above web site.
+
+=cut 
 
 =head1 AUTHOR
 
-Kazuharu Gaou Arakawa, gaou@g-language.org
-
-=head1 SEE ALSO
-
-perl(1).
+Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 
 =cut
